/******************************************************************************\
 *           ___        __                                                    *
 *          /\_ \    __/\ \                                                   *
 *          \//\ \  /\_\ \ \____    ___   _____   _____      __               *
 *            \ \ \ \/\ \ \ '__`\  /'___\/\ '__`\/\ '__`\  /'__`\             *
 *             \_\ \_\ \ \ \ \L\ \/\ \__/\ \ \L\ \ \ \L\ \/\ \L\.\_           *
 *             /\____\\ \_\ \_,__/\ \____\\ \ ,__/\ \ ,__/\ \__/.\_\          *
 *             \/____/ \/_/\/___/  \/____/ \ \ \/  \ \ \/  \/__/\/_/          *
 *                                          \ \_\   \ \_\                     *
 *                                           \/_/    \/_/                     *
 *                                                                            *
 * Copyright (C) 2011, 2012                                                   *
 * Dominik Charousset <dominik.charousset@haw-hamburg.de>                     *
 *                                                                            *
 * This file is part of libcppa.                                              *
 * libcppa is free software: you can redistribute it and/or modify it under   *
 * the terms of the GNU Lesser General Public License as published by the     *
 * Free Software Foundation, either version 3 of the License                  *
 * or (at your option) any later version.                                     *
 *                                                                            *
 * libcppa is distributed in the hope that it will be useful,                 *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                       *
 * See the GNU Lesser General Public License for more details.                *
 *                                                                            *
 * You should have received a copy of the GNU Lesser General Public License   *
 * along with libcppa. If not, see <http://www.gnu.org/licenses/>.            *
\******************************************************************************/


#ifndef CPPA_SCHEDULING_HINT_HPP
#define CPPA_SCHEDULING_HINT_HPP

namespace cppa {

/**
 * @brief Denotes whether a user wants an actor to take part in
 *        cooperative scheduling or not.
 */
enum scheduling_hint {

    /**
     * @brief Indicates that an actor takes part in cooperative scheduling.
     */
    scheduled,

    /**
     * @brief Indicates that an actor should run in its own thread.
     */
    detached,

    /**
     * @brief Indicates that an actor should run in its own thread,
     *        but it is ignored by {@link await_others_done()}.
     */
    detached_and_hidden,

    /**
     * @brief Indicates that an actor takes part in cooperative scheduling,
     *        but it is ignored by {@link await_others_done()}.
     */
    scheduled_and_hidden

};

} // namespace cppa

#endif // CPPA_SCHEDULING_HINT_HPP
